@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.17_02'; # TRIAL VERSION
+our $VERSION = '1.19_01'; # TRIAL VERSION
 
 
 use 5.006;
@@ -12,7 +12,7 @@ use Exporter         ();
 use File::Spec       ();
 use File::Spec::Unix ();
 use Probe::Perl      ();
-use IPC::Run3        qw( run3 );
+use Capture::Tiny    qw( capture );
 use Test::Builder    ();
 use File::Temp       ();
 use File::Path       ();
@@ -67,24 +67,6 @@ sub path ($) {
   );
 }
 
-## This can and should be removed if/when IPC::Run3 is fixed on MSWin32
-## See rt94685, rt46333, rt95308 and IPC-Run3/gh#9"
-sub _borked_ipc_run3 () {
-  $^O eq 'MSWin32' &&
-  ! eval { IPC::Run3::run3 [ perl, -e => 'BEGIN {die}' ], \undef, \undef, \undef; 1 }
-}
-
-if(_borked_ipc_run3())
-{
-  no warnings 'redefine';
-  *run3 = sub {
-    $! = 0;
-    my $r = IPC::Run3::run3(@_, { return_if_system_error => 1 });
-    Carp::croak($!) if $! && $! !~ /Inappropriate I\/O control operation/;
-    $r;
-  };
-}
-
 #####################################################################
 # Test Functions
 
@@ -97,15 +79,12 @@ sub script_compiles {
   my @libs   = map { "-I$_" } grep {!ref($_)} @INC;
   my $dir    = _preload_module();
   my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', '-c', $path, @$args ];
-  my $stdin  = '';
-  my $stdout = '';
-  my $stderr = '';
-  my $rv     = eval { run3( $cmd, \$stdin, \$stdout, \$stderr ) };
+  my ($stdout, $stderr) = capture { system(@$cmd) };
   my $error  = $@;
   my $exit   = $? ? ($? >> 8) : 0;
   my $signal = $? ? ($? & 127) : 0;
   my $ok     = !! (
-    $error eq '' and $rv and $exit == 0 and $signal == 0 and $stderr =~ /syntax OK\s+\z/si
+    $error eq '' and $exit == 0 and $signal == 0 and $stderr =~ /syntax OK\s+\z/si
   );
 
   File::Path::rmtree($dir);
@@ -119,9 +98,9 @@ sub script_compiles {
   return $ok;
 }
 
-# this is noticably slower for long @INC lists (sometimes present in cpantesters
+# this is noticeably slower for long @INC lists (sometimes present in cpantesters
 # boxes) than the previous implementation, which added a -I for every element in
-# @INC.  (also slower for more reasonable @INCs, but not noticably).  But it is
+# @INC.  (also slower for more reasonable @INCs, but not noticeably).  But it is
 # safer as very long argument lists can break calls to system
 sub _preload_module
 {
@@ -129,10 +108,10 @@ sub _preload_module
   # this is hopefully a pm file that nobody would use
   my $filename = File::Spec->catfile($dir, '__TEST_SCRIPT__.pm');
   my $fh;
-  open($fh, '>', $filename) 
+  open($fh, '>', $filename)
     || die "unable to open $filename: $!";
   print($fh 'unshift @INC, ',
-    join ',', 
+    join ',',
     # quotemeta is overkill, but it will make sure that characters
     # like " are quoted
     map { '"' . quotemeta($_) . '"' }
@@ -154,13 +133,13 @@ sub script_runs {
   my $pargs  = _perl_args($path);
   my $dir    = _preload_module();
   my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', $path, @$args ];
-     $stdout = '';
-     $stderr = '';
-  my $rv     = eval { run3( $cmd, $opt->{stdin}, $opt->{stdout}, $opt->{stderr} ) };
+  $stdout = '';
+  $stderr = '';
+  (${$opt->{stdout}}, ${$opt->{stderr}}) = capture { system(@$cmd) };
   my $error  = $@;
   my $exit   = $? ? ($? >> 8) : 0;
   my $signal = $? ? ($? & 127) : 0;
-  my $ok     = !! ( $error eq '' and $rv and $exit == $opt->{exit} and $signal == $opt->{signal} );
+  my $ok     = !! ( $error eq '' and $exit == $opt->{exit} and $signal == $opt->{signal} );
 
   File::Path::rmtree($dir);
 
@@ -176,10 +155,10 @@ sub script_runs {
 sub _like
 {
   my($text, $pattern, $regex, $not, $name) = @_;
-  
+
   my $ok = $regex ? $text =~ $pattern : $text eq $pattern;
   $ok = !$ok if $not;
-  
+
   my $test = Test::Builder->new;
   $test->ok( $ok, $name );
   unless($ok) {
@@ -192,7 +171,7 @@ sub _like
       $test->diag( "  $_" ) for split /\n/, $pattern;
     }
   }
-  
+
   $ok;
 }
 
@@ -215,7 +194,7 @@ sub script_stdout_isnt
 
 sub script_stdout_like
 {
-  my($pattern, $name) = @_;  
+  my($pattern, $name) = @_;
   @_ = ($stdout, $pattern, 1, 0, $name || 'stdout matches' );
   goto &_like;
 }
@@ -247,7 +226,7 @@ sub script_stderr_isnt
 
 sub script_stderr_like
 {
-  my($pattern, $name) = @_;  
+  my($pattern, $name) = @_;
   @_ = ($stderr, $pattern, 1, 0, $name || 'stderr matches' );
   goto &_like;
 }
@@ -296,7 +275,7 @@ sub _perl_args {
 
 sub _options {
   my %options = ref($_[0]->[0]) eq 'HASH' ? %{ shift @{ $_[0] } }: ();
-  
+
   $options{exit}   = 0        unless defined $options{exit};
   $options{signal} = 0        unless defined $options{signal};
   my $stdin = '';
@@ -334,7 +313,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.17_02
+version 1.19_01
 
 =head1 SYNOPSIS
 
@@ -373,7 +352,7 @@ platform safety, this module will err on the side of platform safety.
 The L</script_compiles> test calls the script with "perl -c script.pl",
 and checks that it returns without error.
 
-The path it should be passed is a relative unix-format script name. This
+The path it should be passed is a relative Unix-format script name. This
 will be localised when running C<perl -c> and if the test fails the local
 name used will be shown in the diagnostic output.
 
@@ -431,13 +410,13 @@ scalar.
 =back
 
 The behavior for any other types is undefined (the current implementation uses
-L<IPC::Run3>, but that may change in the future).
+L<Capture::Tiny>).
 
 =item stdout
 
 Where to send the standard output to.  If you use this option, then the the
 behavior of the C<script_stdout_> functions below are undefined.  The value
-may be one of 
+may be one of
 
 =over 4
 
@@ -452,7 +431,7 @@ Is considered to be a filename.
 In which case the standard output will be places into the referenced scalar
 
 The behavior for any other types is undefined (the current implementation uses
-L<IPC::Run3>, but that may change in the future).
+L<Capture::Tiny>).
 
 =item stderr
 
@@ -464,14 +443,14 @@ Same as C<stdout> above, except for stderr.
 
  script_stdout_is $expected_stdout, $test_name;
 
-Tests if the output to stdout from the previous L</script_runs> matches the 
+Tests if the output to stdout from the previous L</script_runs> matches the
 expected value exactly.
 
 =head2 script_stdout_isnt
 
  script_stdout_is $expected_stdout, $test_name;
 
-Tests if the output to stdout from the previous L</script_runs> does NOT match the 
+Tests if the output to stdout from the previous L</script_runs> does NOT match the
 expected value exactly.
 
 =head2 script_stdout_like
@@ -492,14 +471,14 @@ expression.
 
  script_stderr_is $expected_stderr, $test_name;
 
-Tests if the output to stderr from the previous L</script_runs> matches the 
+Tests if the output to stderr from the previous L</script_runs> matches the
 expected value exactly.
 
 =head2 script_stderr_isnt
 
  script_stderr_is $expected_stderr, $test_name;
 
-Tests if the output to stderr from the previous L</script_runs> does NOT match the 
+Tests if the output to stderr from the previous L</script_runs> does NOT match the
 expected value exactly.
 
 =head2 script_stderr_like
@@ -523,14 +502,6 @@ It should work on Perl 5.6.x and I may even test on 5.6.2.  I will accept
 patches to maintain compatibility for such older Perls, but you may
 need to fix it on 5.6.x / 5.8.0 and send me a patch.
 
-This module uses L<IPC::Run3> to compile and run scripts.  There are a number of
-outstanding issues with this module, and maintenance for L<IPC::Run3> is not swift.
-One of these is that L<IPC::Run3> incorrectly throws an exception on Windows when
-you feed it a Perl script with a compile error.  Currently L<Test::Script> probes
-for this bug (it checks for the bug, not for a specific version) and applies a
-workaround in that case.  I am hoping to remove the work around once the bug is
-fixed in L<IPC::Run3>.
-
 =head1 SEE ALSO
 
 L<Test::Script::Run>, L<Test::More>
@@ -547,7 +518,7 @@ Brendan Byrd
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006 by Adam Kennedy.
+This software is copyright (c) 2017 by Adam Kennedy.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
